@@ -14,7 +14,6 @@
 
 from json import JSONDecodeError
 
-import uvicorn
 from asgi_correlation_id import CorrelationIdMiddleware
 from fastapi import FastAPI
 from superlinked.framework.common.parser.exception import MissingIdException
@@ -34,30 +33,27 @@ from superlinked.server.router.management_router import router as management_rou
 
 class ServerApp:
     def __init__(self) -> None:
-        self.app_config = AppConfig()
-        self.app = self.create_app()
+        self.app = self._create_app()
 
-    def setup_executor_handlers(self) -> None:
-        self.app.add_exception_handler(ValueNotProvidedException, handle_bad_request)
-        self.app.add_exception_handler(MissingIdException, handle_bad_request)
-        self.app.add_exception_handler(JSONDecodeError, handle_bad_request)
-        self.app.add_exception_handler(ValueError, handle_bad_request)
-        self.app.add_exception_handler(Exception, handle_generic_exception)
+    def _setup_executor_handlers(self, app: FastAPI) -> None:
+        app.add_exception_handler(ValueNotProvidedException, handle_bad_request)
+        app.add_exception_handler(MissingIdException, handle_bad_request)
+        app.add_exception_handler(JSONDecodeError, handle_bad_request)
+        app.add_exception_handler(ValueError, handle_bad_request)
+        app.add_exception_handler(Exception, handle_generic_exception)
 
-    def create_app(self) -> FastAPI:
+    def _create_app(self) -> FastAPI:
+        app_config = AppConfig()
         logs_to_suppress = ["sentence_transformers"]
-        ServerLoggerConfigurator.setup_logger(self.app_config, logs_to_suppress)
+        ServerLoggerConfigurator.setup_logger(app_config, logs_to_suppress)
 
-        self.app = FastAPI(lifespan=lifespan)
-        self.setup_executor_handlers()
-        self.app.include_router(management_router)
+        app = FastAPI(lifespan=lifespan)
+        self._setup_executor_handlers(app)
+        app.include_router(management_router)
 
-        add_timing_middleware(self.app)
-        self.app.add_middleware(CorrelationIdMiddleware)  # This must be the last middleware
+        add_timing_middleware(app)
+        app.add_middleware(CorrelationIdMiddleware)  # This must be the last middleware
 
         register_dependencies()
 
-        return self.app
-
-    def run(self) -> None:
-        uvicorn.run(self.app, host=self.app_config.SERVER_HOST, port=self.app_config.SERVER_PORT, log_config=None)
+        return app
